@@ -14,12 +14,17 @@ class Backend:
         self._app_helper.SetImageEncoding(0)
 
     def id(self, vtk_obj):
+        if not vtk_obj:
+            return ""
         return str(self._app_helper.GetObjectIdMap().GetGlobalId(vtk_obj))
 
     def object(self, vtk_id):
         return self._app_helper().GetObjectIdMap().GetVTKObject(int(vtk_id))
 
     def mesh(self, dataset, field_to_keep=None, point_arrays=None, cell_arrays=None):
+        if dataset.IsA("vtkAlgorithm"):
+            dataset.Update()
+            dataset = dataset.GetOutput()
         return mesh(
             dataset,
             field_to_keep=field_to_keep,
@@ -79,6 +84,7 @@ class Backend:
             vtkWebPublishImageDelivery,
             vtkWebLocalRendering,
         )
+        from .addon_serializer import registerAddOnSerializers
 
         # Initialize vtk application helper
         self._protocol.setSharedObject("app", self._app_helper)
@@ -90,6 +96,8 @@ class Backend:
 
         # Remote rendering - geometry delivery
         self._protocol.registerLinkProtocol(vtkWebLocalRendering())
+        # Add custom serializer ahead of proper vtk integration
+        registerAddOnSerializers()
 
         # Register custom protocols
         if self._create_protocols:
