@@ -9,6 +9,7 @@ from .utils import (
     abs_path,
     monitor,
     clean_state,
+    clean_value,
     base_directory,
 )
 from .backends import create_backend
@@ -40,7 +41,7 @@ class App:
         self.state = {}
         self.scripts = []
         self.styles = []
-        self.vue_use = ["vuetify", "router", "vtk"]
+        self.vue_use = ["vuetify"]
         self.serve = {}
         self.launcher = {}
 
@@ -62,9 +63,77 @@ class App:
         # CLI argument handling
         self._parser = None
 
-        # Watch template if debug=True
-        if self._debug:
-            pass
+        # protocols to register
+        self._protocols_to_register = []
+
+        # Use ./template.html if available
+        if os.path.exists(abs_path("./template.html", self._root)):
+            self.layout = "./template.html"
+
+    def __getitem__(self, item):
+        return getattr(self, item)
+
+    # -------------------------------------------------------------------------
+    # State management helpers
+    # -------------------------------------------------------------------------
+
+    def listen(self, *_args):
+        """
+        This method needs to be call explicitly if the server expect to use
+        a state variable that can be updated by the client but that is not
+        listed inside any @app.change(). This allow the server to properly
+        describe to the client its dependencies at initialization time.
+        This usually happen when app.get() is called inside methods and
+        does not need to leverage the @app.change() callback on itself.
+        """
+        for name in _args:
+            self._server_keys.add(name)
+
+    def flush_state(self, *_args):
+        state_to_flush = {}
+        if len(_args):
+            for key in _args:
+                state_to_flush[key] = clean_value(self.state[key])
+        else:
+            # flush any pending ChangeHandler
+            for change_handler in self._change_handlers:
+                state_to_flush.update(change_handler.modified_state)
+
+        if self.protocol:
+            self.protocol.push_state_change(state_to_flush)
+
+    def flush_actions(self):
+        actions_to_flush = []
+        for change_handler in self._change_handlers:
+            actions_to_flush.extend(change_handler.actions)
+            change_handler.clear_actions()
+
+        if self.protocol and len(actions_to_flush):
+            self.protocol.push_actions(actions_to_flush)
+
+    # -------------------------------------------------------------------------
+    # Initialization helper
+    # -------------------------------------------------------------------------
+
+    def enableModule(self, module):
+        for key in ["scripts", "styles", "vue_use"]:
+            if key in module.__dict__:
+                setattr(self, key, self[key] + module.__dict__[key])
+
+        for key in ["state", "serve", "vuetify"]:
+            if key in module.__dict__:
+                self[key].update(module.__dict__[key])
+
+    def disableModule(self, module):
+        for key in ["scripts", "styles", "vue_use"]:
+            if key in module.__dict__:
+                for item in module.__dict__[key]:
+                    self[key].remove(item)
+
+        for key in ["state", "serve", "vuetify"]:
+            if key in module.__dict__:
+                for entry in module.__dict__[key]:
+                    del self[key][entry]
 
     # -------------------------------------------------------------------------
     # Annotations
@@ -181,7 +250,12 @@ class App:
     # -------------------------------------------------------------------------
 
     def set(self, key, value, force=False):
-        if key not in self.state or self.state[key] != value or force:
+        if (
+            key not in self.state
+            or self.state[key] != value
+            or force
+            or key not in self._server_keys
+        ):
             self.state[key] = value
             for change_handler in self._change_handlers:
                 change_handler.modified(key, value)
@@ -279,6 +353,9 @@ class App:
 
     # -------------------------------------------------------------------------
 
+    def add_protocol(self, protocol):
+        self._protocols_to_register.append(protocol)
+
     @property
     def protocol(self):
         return self._backend._protocol
